Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

131 documents were found matching the selected criteria.
Page: [ 1] 2 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State ex rel. Hadley v. Pike | 14 CO 14 | Prohibition; mandamus; trial court should have dismissed complaint filed by an out-of-state attorney not licensed in Ohio; writ granted. | Per Curiam | 7/25/2014 | 2014-Ohio-3310
State v. Crooms | 11 CO 17; 12 CO 9 | Fifth Amendment; Sixth Amendment; supplement the record; Crim.R. 29; Crim.R. 12; pre-trial statement; right to counsel; motion to suppress. | Waite | 6/30/2014 | 2014-Ohio-2928
State v. Smith | 13 CO 10 | OVI; R.C. 4511.19(A)(1); motion to suppress; field sobriety tests administered without reference to NHTSA or similar standards are inadmissible; probable cause to arrest; probable cause to administer field sobriety tests; officer may conduct a brief stop based on a corroborated anonymous tip; officer may ask driver of a parked vehicle for identification without violating the Fourth Amendment; reversed in part. | Waite | 6/27/2014 | 2014-Ohio-2933
In re C.W. | 13 CO 44; 13 CO 45; 13 CO 46 | Removal of a guardian; R.C. 2111.50(A)(2)(c); guardian ad litem was permitted to testify to events she observed during her guardianship even though the term of the guardianship had expired by the time the hearing to appoint a successor guardian took place; Sup.R. 48(D); manifest weight; affirmed. | Waite | 6/26/2014 | 2014-Ohio-2934
State v. Rose | 12 JE 18 | Aggravated robbery; felonious assault; weight of the evidence; ineffective assistance of counsel; consecutive sentences; allied offenses; merger. | Waite | 6/26/2014 | 2014-Ohio-2929
Pankey v. Mahoning Cty. Court of Common Pleas | 13 MA 108 | Declaratory Judgment Action; Sex offender registration; Megan’s Law. | Vukovich | 6/25/2014 | 2014-Ohio-2940
State v. Scott | 13 MA 47 | Consecutive sentences; findings; R.C. 2929.14(C)(4); sentencing hearing; State v. Kalish, 120 Ohio St.3d 23, 2008-Ohio-4912. | Waite | 6/24/2014 | 2014-Ohio-2993
Pankey v. State | 13 MA 147 | Motion to terminate sexual offender requirements; Megan’s Law; Adam Walsh Act; Civ.R. 60(B); defendant failed to appeal judgment entry imposing registration requirements; res judicata; affirmed. | Waite | 6/24/2014 | 2014-Ohio-2942
Bank of Am. N.A. v. Miller | 13-CA-894 | foreclosure; default judgment; standing; real party in interest; Civ.R. 60(B); common-law motion to vacate; | Donofrio | 6/24/2014 | 2014-Ohio-2932
State v. Miller | 13 MA 12 | Aggravated murder with firearm specification and tampering with evidence; Appellant unambiguously invoked his right to cut off questioning which the police failed to scrupulously honor and thus the subsequent statements at the first interview should have been suppressed; Appellant later reinitiated conversation from the transport area so that his final story was properly admitted; Retold story to girlfriend; As final story (admitting he shot the victim) was properly admitted, it was harmless to admit earlier story (claiming he witnessed a shooting by an unidentified intruder); Jury instruction for tampering with evidence and consciousness of guilt; Sufficiency of the evidence to prove tampering; Ineffective assistance; State concedes court failed to make consecutive sentence findings and improperly imposed five mandatory years of post-release control on tampering with evidence instead of three discretionary years. | Vukovich | 6/23/2014 | 2014-Ohio-2936
Roghelia v. Hopedale Mining, L.L.C. | 13 HA 8 | Directed verdict; perceived disability; accommodation; Reason for the termination; Questions for the jury. | Vukovich | 6/23/2014 | 2014-Ohio-2935
Van Horn v. Thomas & King | 13 MA 124 | summary judgment; plaintiff slipped and fell on ice on restaurant sidewalk; open and obvious doctrine; natural or unnatural accumulation of ice; genuine issues of material fact exist | Donofrio | 6/20/2014 | 2014-Ohio-2941
B.J. Alan Co. v. Andrews | 13 MA 55 | Trial court did not abuse its discretion staying discovery pending resolution of the summary judgment motion; Summary judgment was appropriately granted because issues raised were either barred by law of the case or res judicata. | Vukovich | 6/20/2014 | 2014-Ohio-2938
Wells Fargo Bank, N.A. v. Murphy | 13 MA 35 | foreclosure; mortgage; assignment; summary judgment; notice of acceleration | Donofrio | 6/20/2014 | 2014-Ohio-2937
Yeager v. Moody | 13-CA-884 | defective design; defective manufacture; summary judgment; pro se litigant; standing; court costs | Donofrio | 6/20/2014 | 2014-Ohio-2931
Portage Exteriors v. Hein Constr., Inc. | 13 BE 5 | construction subcontract was complete agreement between parties; parol evidence rule precluded extrinsic evidence; warranty was not required by subcontract; Prompt Pay claim; hearing on attorney fees | Donofrio | 6/20/2014 | 2014-Ohio-2930
State v. Holmes | 13-MA-76 | gross sexual imposition; R.C. 2907.05(A)(1)(C)(1); fourth-degree felony; importuning; R.C. 2907.07(B)(1)(F)(3); fifth-degree felony; consecutive sentences; R.C. 2929.14(C)(4); judicial fact-finding duties | Donofrio | 6/19/2014 | 2014-Ohio-2724
State v. Watters | 13 MA 151 | unauthorized use of a motor vehicle; R.C. 2913.03(A)(D)(1)(2); first-degree misdemeanor; community control; restitution statute; R.C. 2929.18(A)(1) | Donofrio | 6/19/2014 | 2014-Ohio-2943
In re M.R. | 13 JE 30 | A juvenile offender registrant; R.C. 2152.83(A) statement that classification shall be made at the time of release from the secure facility is not a double jeopardy violation; Rational basis for statute to differentiate between juveniles of different ages; Continuing the classification beyond age 21 does not violate due process or constitute cruel and unusual punishment. | Vukovich | 6/16/2014 | 2014-Ohio-2623
State ex rel. DeWine v. Crock Constr. Co. | 13 NO 405 | Res judicata; privity; issue preclusion; claim-preclusion; OEPA; environmental enforcement; agreed order; Civ.R. 3, 8, 9; R.C. 3714.01 et seq. | Waite | 6/16/2014 | 2014-Ohio-2944
State v. Morgan | 13 MA 126 | Sentence was not an abuse of discretion; Sentence did not place an unnecessary burden on the state; Notice Judgment Entry, which was incorporated, did not clearly indicate sexual offender classification; R.C. 2929.19; Classification must be in judgment entry; Matter remanded. | Vukovich | 6/13/2014 | 2014-Ohio-2625
Robenolt v. Zyznar | 13-MA-129 | real estate sales contract; deed; equity; reformation; merger; mutual mistake | Donofrio | 6/13/2014 | 2014-Ohio-2593
State v. Jones | 13-MA-53 | post-conviction relief; untimely; successive; 2011 H.B. 86 | Donofrio | 6/13/2014 | 2014-Ohio-2592
State v. Christian | 12-MA-164 | felony fleeing and eluding; speedy trial; juror excused for cause; prosecutor’s comments and questions did not constitute misconduct; sufficient evidence supported conviction; conviction was not against the manifest weight of the evidence; no cumulative error | Donofrio | 6/13/2014 | 2014-Ohio-2590
State v. Mendez | 13 MA 86 | Felony theft; restitution; R.C. 2929.18(A)(1); defendant challenged the amount of restitution and was entitled to a hearing to determine restitution; restitution may be more than the monetary amount categorizing the degree of a theft charge; restitution cannot be greater than the amount of economic loss suffered by the victim; State v. Lalain, 136 Ohio St.3d 248. | Waite | 6/13/2014 | 2014-Ohio-2601
Ponzi v. Trimboli | 13 MA 43 | Breach of fiduciary duty; conversion; some errors on appeal waived after failure to object to magistrate's decision; record reveals a mathematical error in the modification of the magistrate's decision regarding the final monetary judgment; judgment modified. | Waite | 6/13/2014 | 2014-Ohio-2600
Jones v. W. Reserve Transit Auth. | 13-MA-41 | breach of contract; negligence; summary judgment; res judicata | Donofrio | 6/12/2014 | 2014-Ohio-2591
State v. Holsinger | Case No. 13 CO 38 | Post-release control, State concedes error; failure to include statement notifying defendant about the consequences of violating post-release control; R.C. 2929.191(C). | DeGenaro | 6/9/2014 | 2014-Ohio-2523
State v. Moore | 13 MA 60 | Sex offender reclassification; S.B. 5; proceeding with hearing while reconsideration motion pending with Court of Appeals; sex offender reclassification hearing. | DeGenaro | 6/4/2014 | 2014-Ohio-2525
State v. Thoennes | 13 MA 52 | Manifest weight; allocution. | DeGenaro | 6/4/2014 | 2014-Ohio-2524
State v. Crankfield | 13 MA 122 | Post-sentence motion to withdraw a no contest plea claimed attorney misadvised him that the offense of child endangering was expungeable when in fact it was not and stated that he would not have pled to the charge had he known the offense was not subject to expungement; Trial court did not err in failing to hold a hearing before denying his plea withdrawal motion filed nearly seven years after plea and five years after final discharge. | Vukovich | 6/3/2014 | 2014-Ohio-2624
Swartz v. Householder | 13 JE 24, 13 JE 25 | 1989 Dormant Mineral Act versus 2006 Dormant Mineral Act; Surface owners’ rights deemed vested under self-executing 1989 DMA; 2006 amendments are not retroactive. | Vukovich | 6/2/2014 | 2014-Ohio-2359
State ex rel. DeWine v. Fred's Party Ctr., Inc. | 13 BE 29 | Trial court admitted lab reports without testimony from authors; Appellant claims no evidence of controlled substance without reports; Attorney general insists reports were admissible under statute that clearly only applies to criminal prosecutions, but appellant allowed testimony that 3 packets from Bridgeport store tested positive; Only issue is test result for Martins Ferry store; Admission harmless under all circumstances; Traditional equity principles do not apply to statutory injunction action with remedies mandated after finding nuisance; Supreme Court exception on whether owner “did not negligently or knowingly acquiesce to, and did not participate in the creation or perpetuation of the nuisance” is a factual matter best left for trial court. | Vukovich | 6/2/2014 | 2014-Ohio-2358
State ex rel. DeWine v. Shadyside Party Ctr. | 13 BE 26 | Appellant does not contest that the store constituted a nuisance due to the store’s habitual selling of herbal incense packets which contained a controlled substance; Appellant argues court erred in ordering the closure of the store for one year, Asserting they were diligent in correcting nuisance and nuisance ceased to exist after search warrant executed, government had unclean hands, and the order should have been narrowly tailored as to extent of abatement and forfeiture of personality; As this is a statutory injunction action, the general equitable principles are inapplicable; Statutory provisions apply as written; Supreme Court exception to the mandatory one-year closure provision for an “owner who did not negligently or knowingly acquiesce to, and did not participate in the creation or perpetuation of the nuisance” could rationally be found to be inapplicable. | Vukovich | 6/2/2014 | 2014-Ohio-2357
Thomaselli v. Thomaselli | 13 JE 18 | divorce; court did not retain jurisdiction over spousal support; determination as to marital or separate property; failure to distribute all accounts; improper taking of judicial notice; financial misconduct finding | Donofrio | 6/2/2014 | 2014-Ohio-2469
Robert W. Moodie Excavating, Inc. v. Smith | 13-JE-4 | balance due on contract for excavation work; alleged double billing; price of slag included in the parties’ agreement; agreed price included contingencies; conflicting evidence on sloped bank | Donofrio | 6/2/2014 | 2014-Ohio-2468
State v. Russell | 13-CO-16 | aggravated robbery; R.C. 2911.01(A)(1); first-degree felony; no-merit brief; ineffective assistance of counsel; juror misconduct | Donofrio | 6/2/2014 | 2014-Ohio-2467
Nau v. Martins Ferry | 13-BE-24 | petition for writ of habeas corpus; appeal was adequate remedy in the ordinary course of law; procedendo | Donofrio | 6/2/2014 | 2014-Ohio-2466
State v. Worley | 13-BE-8 | sexual battery; R.C. 2907.03(A)(5); second-degree felony; jail-time-credit; court costs; Am.Sub.S.B. No. 10 (S.B. 10); Adam Walsh Act; State v. Williams, 129 Ohio St.3d 344, 2011-Ohio-3374, 344, 952 N.E.2d 1108; State v. Joseph, 125 Ohio St.3d 76, 2010-Ohio-954, 926 N.E.2d 278; | Donofrio | 6/2/2014 | 2014-Ohio-2465
Fry v. Hanni | 13-MA-99 | legal malpractice; statute of limitations; summary judgment | Donofrio | 5/29/2014 | 2014-Ohio-2346
State v. Ramey | 13-MA-64 | domestic violence; R.C. 2919.25(A), first-degree misdemeanor; no-merit brief; Anders v. California, 386 U.S. 738, 87 S.Ct. 1396, 18 L.Ed.2d 493 (1967); State v. Toney, 23 Ohio App.2d 203, 262 N.E.2d 419 (7th Dist.1970); Crim.R. 11 plea colloquy; misdemeanor sentencing | Donofrio | 5/29/2014 | 2014-Ohio-2345
Price v. K.A. Brown Oil and Gas, L.L.C. | 13 MO 13 | Oil and gas lease; provision of lease required oil company to put two existing wells into production by November 1989; second well was not put into production until 1995; lease is declared terminated; affirmed. | Waite | 5/27/2014 | 2014-Ohio-2298
State v. Esmail | 13 CO 35 | Drug trafficking; trial court was permitted to rely on prior drug conviction that was later dismissed in Drug Court; no evidence in record that judge actually relied on the prior dismissed conviction; defendant had a history of drug crimes that warranted consecutive sentences; affirmed. | Waite | 5/27/2014 | 2014-Ohio-2297
State v. Jones | 13 MA 101 | Felony convictions for attempted rape and gross sexual imposition; consecutive sentences; R.C. 2929.14(C)(4); record reflects that trial judge made required findings to impose consecutive sentences both at the sentencing hearing and in its judgment entry; affirmed. | Waite | 5/23/2014 | 2014-Ohio-2248
State v. Raynovich | 12 MA 65 | Theft conviction; R.C. 2913.02; defendant charged with felony theft after stealing $549 from Rite Aid; theft statute changed during pendency of case, raising amount necessary for felony theft to $1,000; defendant receives the benefit of the change in law and should have only been convicted and sentenced for misdemeanor; R.C. 1.58(B); State v. Taylor, 138 Ohio St.3d 194. | Waite | 5/23/2014 | 2014-Ohio-2246
State v. Jackson | 13 MA 121 | No ineffective assistance of counsel for withdrawing suppression motion; No indication of extended detention awaiting canine unit; No discernible issue with order of sentences. | Vukovich | 5/22/2014 | 2014-Ohio-2249
State v. Durkin | 13 MA 36 | Anders brief; No appealable issues; Convictions and sentence affirmed. | Vukovich | 5/22/2014 | 2014-Ohio-2247
State v. Toma | 13 CO 19 | unlawful sexual conduct with a minor; R.C. 2929.12 seriousness and recidivism factors; trial court’s statements and judgment entry demonstrate that it considered the statutory factors | Donofrio | 5/20/2014 | 2014-Ohio-2256
Howard v. Miller | 14 BE 15 | Writ of habeas corpus; R.C. 2725.04. | Per Curiam | 5/12/2014 | 2014-Ohio-2100
State v. Hill | 13 CA 892 | Felony Sentencing; Non-minimum sentence did not amount to an abuse of discretion; Remand for consecutive sentencing findings. | Vukovich | 5/5/2014 | 2014-Ohio-1965
PNC Mtge. v. Garland | 12 MA 222 | Certify conflict; factual distinctions not a basis for certification. | Per Curiam | 5/2/2014 | 2014-Ohio-1944
State v. Koczwara | 13 MA 149 | Officer can ask any lawfully stopped driver to alight from vehicle during the traffic stop without any justification; Officer’s subjective motivations do not invalidate a constitutionally permissible stop and its components; Fact that officer asked driver out with a desire to conduct field sobriety tests (at a point when he allegedly did not yet have reasonable suspicion of OVI) does not invalidate the order to alight from the vehicle; Instability on exiting vehicle can be considered reasonable suspicion evaluation for field testing. | Vukovich | 5/1/2014 | 2014-Ohio-1946
State v. Croom | 12 MA 54 | Application for reconsideration dismissed as untimely; Application for reopening denied on the ground that appellate counsel was not ineffective for refusing to brief an argument which relies on evidence outside of the trial court record. | Per Curiam | 5/1/2014 | 2014-Ohio-1945
State v. Jordan | 06 HA 586 | App.R. 26(B); application for re-opening; untimely; no good cause. | Per Curiam | 4/28/2014 | 2014-Ohio-1943
State v. Hufnagel | 12 MA 195 | Domestic violence; manifest weight; proof of physical harm; conviction can be sustained on the basis of a single witness; a victim is permitted to make a statement at sentencing and recommend a sentence; R.C. 2930.14(B); affirmed. | Waite | 4/21/2014 | 2014-Ohio-1799
Walker v. Shondrick-Nau | 13 NO 402 | : quiet title to mineral estate; summary judgment; Ohio’s Dormant Mineral Act; 1989 version of R.C. 5301.56; 2006 version of R.C. 5301.56; subject of a title transaction; Dodd v. Croskey, 7th Dist. No. 12 HA 6, 2013-Ohio-4257; vested property right; constitutionality of statute waived when not raised in trial court | Donofrio | 4/3/2014 | 2014-Ohio-1499
State v. Coleman | 13 CO 3 | R.C. 4511.19; motion for discharge; motion to suppress; speedy trial; R.C. 2945.71(C)(2); R.C.4511.191(A); implied consent. | DeGenaro | 3/31/2014 | 2014-Ohio-1498
State v. Dixon | 13 MA 87 | Anders v. California, 386 U.S. 738, 87 S.Ct. 1396 (1967); State v. Toney, 23 Ohio App.2d 203, 262 N.E.2d 419 (7th Dist.1970); Independent review reveals no appealable issues; Motion to withdraw granted. | Vukovich | 3/31/2014 | 2014-Ohio-1474
Aqua Ohio, Inc. v. Allied Indus. Dev. Corp., Inc. | 13 MA 85 | Affirm trial court’s grant of JNOV; Contract did not provide for damages for interference with the development of the property; Contract only provided for damages for result from the operation, use or maintenance of the waterline; No evidence was submitted to show damages from operation, use or maintenance of the waterline. | Vukovich | 3/31/2014 | 2014-Ohio-1473
CitiMortgage, Inc. v. Rudzik | 13 MA 20 | Civ.R. 12(B)(6) motion; Counterclaim sufficiently pled theft offense; Pursuant to R.C 2307.60 and 2307.61 there is a civil cause of action for damages that result from a theft offense; R.C. 2307.61(G) specifically indicates that recovery of damages in a civil action for a theft offense does not require a criminal conviction. | Vukovich | 3/31/2014 | 2014-Ohio-1472
Teeter v. Teeter | 13 CA 887 | Summary judgment; Constructive trust; The burden of proof to obtain the equitable remedy of a constructive trust is on the party seeking to have it imposed and that party must prove the case by a clear and convincing standard of proof; Given the nature of this case, i.e. the fact that it is a he said/she said type of case, appellant could meet this burden if the trier of fact believes her; Grant of summary judgment reversed. | Vukovich | 3/31/2014 | 2014-Ohio-1471
State v. Fasline | 12 MA 221 | Suppression; Trial court ruling that consent to search home was not voluntary was supported by competent credible evidence. | Vukovich | 3/31/2014 | 2014-Ohio-1470
Homeowners Assn. at Arrowhead Bay v. Fidoe | 12 MA 136 | Pursuant to R.C. 5311.19(B)(1), an eviction action initiated by unit owner’s association shall be brought by the association, as the unit owner’s agent, in the name of the unit owner; Eviction action dismissed for failing to bring action in the name of the unit owner. | Vukovich | 3/31/2014 | 2014-Ohio-1469
State v. McCrary | 12 MA 135 | Discretionary bindover; Excited utterance; Relevancy; No material prejudice; Photo line-up; Blinded administrator without writing explaining why; Manifest weight | Vukovich | 3/31/2014 | 2014-Ohio-1468
Bigler v. Personal Serv. Ins. Co. | 12 BE 10 | Bad faith refusal of coverage; BMV returned SR-22 to insurer for corrections; After insurer cancelled policy; Insurer claims that SR-26 was not required due to subsequent BMV return; Attorney fee award not unreasonable based on quarter-hour billing increments, $400 hourly rate for lead attorneys, time reconstruction, and 2.0 multiplier. | Vukovich | 3/31/2014 | 2014-Ohio-1467
In re Estate of Montgomery | 13 JE 20 | Probate estate; final accounting; failure to object to distribution or appeal the court’s approval of the final account waives errors on appeal. | Waite | 3/31/2014 | 2014-Ohio-1401
Ohio Bur. of Workers’ Comp. v. McKinley | 12 CO 41 | Workers’ compensation; R.C. 4123.931(G); BWC may collect its subrogation interest from a third party if it does not receive notice of settlement talks, have a reasonable opportunity to assert its subrogation rights, or if the settlement or compromise excludes any amount paid by BWC; record reflects that BWC received notice of settlement negotiations between claimant and tortfeasor, and had reasonable opportunity to present its claim; mere failure to mention lien in settlement did not constitute exclusion of the claim because settlement amount was well in excess of the lien and BWC could use statutory procedure to collect from the settlement. | Waite | 3/31/2014 | 2014-Ohio-1397
State v. Rucci | 13 MA 65, 13 MA 66, 13 MA 67, 13 MA 68, 13 MA 69, 13 MA 70, 13 MA 71, 13 MA 72 | Civ.R. 60(B)(4); Civ.R. 57(B); direct appeal; jurisdiction | DeGenaro | 3/28/2014 | 2014-Ohio-1396
Burke v. Burke | 13 MA 24 | Contempt for failure to pay spousal support; purge condition to remove contempt cannot regulate future conduct; purge mechanism must be clear and allow a reasonable opportunity to satisfy the purge condition; purge condition required payment of an additional $100 per month without specifying total amount to be paid, length of time, or ability to pay; remanded for new purge condition. | Waite | 3/28/2014 | 2014-Ohio-1402
Tuckosh v. Cummings | 13 HA 1 | Post-divorce motion; convert prior delinquencies in child/spousal support and other monetary aspects of divorce decree into a lump sum judgment; trial court complied with ex-wife’s motion, but could not render lump sum judgment on matters that were not quantifiable from the record; affirmed. | Waite | 3/28/2014 | 2014-Ohio-1400
State v. Smith | 12 MA 168 | Attempted rape; kidnapping; felonious assault; allied offenses; guilty plea; consecutive sentences; R.C. 2929.14(C)(4); consecutive sentencing provisions of H.B. 86 applies to defendants sentenced on or after September 30, 2011; trial court failed to make required findings supporting consecutive sentences; remand for resentencing. | Waite | 3/28/2014 | 2014-Ohio-1398
State v. Fuller | 12 MA 185 | attempted murder; felonious assault; merger; manifest weight of the evidence; in-court identification after witness was unable to positively identify appellant in photo lineup | Donofrio | 3/27/2014 | 2014-Ohio-1351
Wells Fargo Bank, N.A. v. Stevens | 12 MA 219 | Civ.R. 60(B)(5); trial court should not have granted relief from judgment because mortgagor did not meet requirements of GTE Automatic Electric, Inc.; mere negotiations with the lender is not a valid defense to a foreclosure action; judgment vacated and judgment in favor of lender reinstated. | Waite | 3/25/2014 | 2014-Ohio-1399
Ramsey v. Ramsey | 13 JE 17 | Refinancing house; Property division; Spousal support; Child support; Imputed income; No abuse of discretion. | Vukovich | 3/24/2014 | 2014-Ohio-1227
State v. Johnson | 13 JE 5 | R.C. 2941.146; State v. Swidas, 133 Ohio St.3d 460; 2012-Ohio-4638, 979 N.E.2d 254. | Vukovich | 3/24/2014 | 2014-Ohio-1226
State v. Thompson | 13 CO 20 | Intimidation includes attempt to influence, hinder, or intimidate; Intent of defendant, not the belief of recipient; Sufficiency; Weight; Ineffective assistance of counsel for failure to list a witness in discovery; Court’s exclusion of that witness as a discovery sanction; Court’s instruction to witness to only answer questions presented; Jury instruction that whether the victim believed the threats was not relevant. | Vukovich | 3/24/2014 | 2014-Ohio-1225
State v. Odey | 13 CO 23 | Anders/Toney brief; disorderly conduct; bench trial;; manifest weight; sentencing; no appealable issues. | DeGenaro | 3/24/2014 | 2014-Ohio-1352
In re I.R.H. | 13 MA 158 | grandparent visitation motion; R.C. 3109.11; trial court failed to give special weight to parent’s wishes and concerns; best interest of child required a grandparent visitation order; standard order of visitation for non-residential parents was too excessive for grandparent visitation | Donofrio | 3/20/2014 | 2014-Ohio-1180
State v. Morris | 13 MA 93 | Drug possession; search warrant; sufficiency of probable cause in affidavit submitted in support of search warrant. | DeGenaro | 3/20/2014 | 2014-Ohio-1177
Lipari v. Tanoff | 13 MA 17 | Manifest weight; failure to file transcript with objections to the magistrate's decision; Civ.R. 53(D)(3)(b)(iii); caveat emptor. | DeGenaro | 3/20/2014 | 2014-Ohio-1176
PNC Mtge. v. Garland | 12 MA 222 | Foreclosure; compliance with HUD regulations; 24 CFR 203.604; 24 CFR 203.605; Civ.R. 9( C); HAMP. | DeGenaro | 3/20/2014 | 2014-Ohio-1173
State v. Stout | 13 MA 30 | Applicability of H.B. 86; possession of child pornography; meaning of 'physical harm' under R.C. 2929.13(B)(1)(b)(11); mandatory community control; mootness. | DeGenaro | 3/19/2014 | 2014-Ohio-1094
State v. Wellington | 13-MA-90 | involuntary manslaughter; R.C. 2929.14(A)(1); H.B. 86; sentence contrary to law | Donofrio | 3/17/2014 | 2014-Ohio-1179
Guerrieri v. Brys | 13-MA-7 | ex parte civil protection order withdrawn; motion for sanctions for alleged frivolous misconduct dismissed | Donofrio | 3/17/2014 | 2014-Ohio-1178
State v. Royal | 12-MA-148 | aggravated murder; aggravated robbery; failure to file judgment on motion to suppress likely due to oversight; photo line-ups not unduly suggestive; R.C. 2933.83; blinded administrator; manifest weight of the evidence; no ineffective assistance of counsel; alleged prosecutorial misconduct; no cumulative error | Donofrio | 3/17/2014 | 2014-Ohio-1175
State v. Freeman | 12 MA 112 | Postrelease control; hearing; omission; sentencing entry; rape; kidnapping; merger. | Waite | 3/14/2014 | 2014-Ohio-1013
State v. Simmons | 13 JE 15 | Allied offenses; error in failure to merge convictions does not result in a void sentence; issue of merger could have been raised in a variety of earlier appeals; res judicata. | Waite | 3/13/2014 | 2014-Ohio-1014
State v. Williams | 11 MA 185 | Crim.R. 29; murder; attempted murder; DNA; manifest weight; sufficiency; concealing evidence; tampering; firearm specification; consecutive sentences; concurrent sentences; confrontation clause. | Waite | 3/11/2014 | 2014-Ohio-1015
State v. Wilson | 13 MA 10 | Knowing, voluntary and intelligent plea; ineffective assistance of counsel; Crim.R. 11(C). | DeGenaro | 3/10/2014 | 2014-Ohio-942
State v. Harding | 13 MA 131 | State confesses judgment, ALS reversed. | Vukovich | 3/6/2014 | 2014-Ohio-884
Freedom Mtge. Corp. v. Milhoan | 13 CO 15 | Bank incorrectly informed trial court there was failure to comply with statutory requirement of service of notice in R.C. 2329.26(A)(1)(a)(i); Notice of sale need not be provided to those in default; Bank misinterpreted (A)(1)(a)(ii) involving filing copy of written notice with proof of service with clerk; Bank erroneously urged that the sale was void; Intervention should have been ordered as a matter of right or by permissive intervention. | Vukovich | 3/6/2014 | 2014-Ohio-881
Patel v. Village of Bellaire | 13 BE 9 | Plaintiff who previously lost at summary judgment stage where he made only a bare allegation that affidavits were false; In a Civ.R. 11 motion for sanctions against the defendant’s attorney, he specifically asserts what parts of the affidavits were allegedly false; No evidence of falsity or that counsel who attached affidavits of law director and fire captain should be sanctioned. | Vukovich | 3/6/2014 | 2014-Ohio-880
State v. Adams | 13 MA 54 | For state's breach of plea agreement, appellate court chose remedy of resentencing before different judge (instead of plea withdrawal) as per United States Supreme Court's Santobello case; State asked for reconsideration arguing our choice of remedy was akin to a disqualification order, which can only be made by the Chief Justice of the Ohio Supreme Court; Reconsideration denied. | Per Curiam | 3/5/2014 | 2014-Ohio-883
State v. Morris | 13 MA 19 | Presentence motion to withdraw his guilty plea on day of sentencing, seven weeks after the plea was entered; Factors do not weigh in favor of plea withdrawal. | Vukovich | 3/5/2014 | 2014-Ohio-882
State v. Lawson | 12 MA 194 | Inferred waiver; Right to counsel; speedy trial; competency evaluation; right to counsel at arraignment for petty offenses; sufficiency of the evidence; manifest weight of the evidence. | Vukovich | 3/5/2014 | 2014-Ohio-879
State v. Brown | 12 MA 202 | Contempt; direct contempt; abuse of discretion. | Waite | 3/5/2014 | 2014-Ohio-896
State v. Winkle | 12 MA 162 | Preindictment delay; investigation closed in 2003 due to lack of evidence; second suspect never investigated; alleged new evidence not disclosed to court at motion to dismiss hearing; defendant prejudiced by loss of substantial pieces of evidence during 9-year delay in prosecution; dismissal of indictment affirmed. | Waite | 3/5/2014 | 2014-Ohio-895
State v. Toda | 13 MA 44 | Withdraw of plea; Crim.R. 32.1; ineffective assistance of counsel. | DeGenaro | 3/4/2014 | 2014-Ohio-943
Tree of Life Church v. Agnew | 12-BE-42 | summary judgment; defamation; libel; slander; accusations against pastor of misappropriation of church funds | Donofrio | 3/4/2014 | 2014-Ohio-878
State v. Wright | 12 MA 143; 12 MA 144 | Defendant held in contempt for failure to register for house arrest; record shows he was already on house arrest at the time he was alleged to have failed to register; state failed to provide proof of the elements of contempt; reversed. | Waite | 2/28/2014 | 2014-Ohio-775

Page: [ 1] 2 next